@@ -43,7 +43,6 @@ my $center_y      = $YY / 2;
 my $factor        = 5;
 
 $F->cls('OFF');
-
 print_it($F, 'Plotting Test');
 my $s = time + $factor;
 while (time < $s) {
@@ -453,6 +452,7 @@ while (time < $s) {
     );
     $F->blit_write($image);
 } ## end while (time < $s)
+
 my $image = $F->load_image(
     {
         'x'      => 0,
@@ -483,6 +483,18 @@ while (time < $s) {
     $F->blit_write($image);
 }
 
+print_it($F,'Testing Resized Image Blitting');
+$s = time + $factor;
+while (time < $s) {
+    my $new = $image;
+    $new->{'newwidth'} = int(rand($XX));
+    $new->{'newheight'} = int(rand($YY));
+    $new = $F->resize_image($new);
+    $new->{'x'} = abs(rand($XX - $new->{'width'}));
+    $new->{'y'} = abs(rand($YY - $new->{'height'}));
+    $F->blit_write($new);
+}
+
 $F->cls('ON');
 
 exit(0);
